# This file was auto-generated by Fern from our API Definition.

import typing

from .source_sync_crawl_settings_output import SourceSyncCrawlSettingsOutput
from .source_sync_google_drive_settings import SourceSyncGoogleDriveSettings
from .source_sync_notion_settings_output import SourceSyncNotionSettingsOutput
from .source_sync_page_crawl_settings_output import SourceSyncPageCrawlSettingsOutput
from .source_sync_sitemap_settings_output import SourceSyncSitemapSettingsOutput
from .source_sync_website_settings import SourceSyncWebsiteSettings

SyncConfigOutputSourceSettings = typing.Union[
    SourceSyncGoogleDriveSettings,
    SourceSyncNotionSettingsOutput,
    SourceSyncCrawlSettingsOutput,
    SourceSyncPageCrawlSettingsOutput,
    SourceSyncSitemapSettingsOutput,
    SourceSyncWebsiteSettings,
]
