# This file was auto-generated by Fern from our API Definition.

import typing

UsageTypes = typing.Union[
    typing.Literal[
        "crawl", "storage", "web_search", "input_tokens", "output_tokens", "text_embedding", "workflow_invocations"
    ],
    typing.Any,
]
