# This file was auto-generated by Fern from our API Definition.

import typing

from .source_sync import SourceSync
from .workflow_execute import WorkflowExecute

SlackTriggerConfigInputAction = typing.Union[SourceSync, WorkflowExecute]
