# This file was auto-generated by Fern from our API Definition.

import typing

AgentRevisionResponseStyle = typing.Union[typing.Literal["precise", "balanced", "creative", "experimental"], typing.Any]
