# This file was auto-generated by Fern from our API Definition.

import typing

NotificationType = typing.Union[
    typing.Literal["usage_limit_reached", "hobby_tier_usage", "payment_failed", "integration_disconnected"], typing.Any
]
