# This file was auto-generated by Fern from our API Definition.

import typing

PlanTypes = typing.Union[
    typing.Literal[
        "plan_1",
        "plan_2",
        "plan_7357",
        "plan_3",
        "plan_4",
        "plan_5",
        "plan_6",
        "plan_7",
        "plan_8",
        "plan_9",
        "plan_10",
        "plan_11",
        "plan_12",
        "plan_13",
    ],
    typing.Any,
]
