# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.kanban_view_settings import KanbanViewSettings
from ...types.table_view_settings import TableViewSettings

CreateViewRequestSettings = typing.Union[KanbanViewSettings, TableViewSettings]
