# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_automation_config import AgentAutomationConfig
from .typescript_automation_config import TypescriptAutomationConfig
from .workflow_automation_config import WorkflowAutomationConfig

DateTimeColumnAutomationConfig = typing.Union[
    AgentAutomationConfig, TypescriptAutomationConfig, WorkflowAutomationConfig
]
