# This file was auto-generated by Fern from our API Definition.

import typing

from .bare_input import BareInput
from .baseline import Baseline
from .default_input import DefaultInput
from .html_2_text import Html2Text

TrafilaturaInputTrafilaturaType = typing.Union[BareInput, Baseline, DefaultInput, Html2Text]
