# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .collection_view_state_output_views_value import CollectionViewStateOutputViewsValue


class CollectionViewStateOutput(UncheckedBaseModel):
    """
    Complete view state for a collection
    """

    views: typing.Optional[typing.Dict[str, CollectionViewStateOutputViewsValue]] = None
    view_ids: typing.Optional[typing.List[str]] = None
    active_view_id: typing.Optional[str] = None
    active_table_id: typing.Optional[str] = None
    display_settings: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    last_synced_at: typing.Optional[dt.datetime] = None
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    organization_id: str
    collection_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
