# This file was auto-generated by Fern from our API Definition.

import typing

from .actor import Actor
from .legacy_identity import LegacyIdentity

DocumentCreatedBy = typing.Union[LegacyIdentity, Actor]
