# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .billing import Billing


class Organization(UncheckedBaseModel):
    """
    We ignore extra properties, other services might be responsible for adding
    to the organization document, we do not care about these extra fields.

    TODO<mark>: We still need the extra bit for now since we still have some
    microservices, like workflow. However once we are a true big boi, we can
    use this model for the organization and not worry about other services
    adding to it.
    """

    billing: typing.Optional[Billing] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
