# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.run_log import RunLog
from ...types.run_log_pagination import RunLogPagination

WorkflowLogsListLogsResponse = typing.Union[RunLog, RunLogPagination]
