# This file was auto-generated by Fern from our API Definition.

import typing

IntegrationConnectionIntegrationType = typing.Union[
    typing.Literal[
        "hubspot",
        "gmail",
        "web_search",
        "slack",
        "google_drive",
        "google_calendar",
        "notion",
        "gsuite",
        "salesforce",
        "linear",
        "github",
        "attio",
        "mcp",
        "square",
        "paypal",
        "sentry",
        "statsig",
        "scout_native_tools",
    ],
    typing.Any,
]
