# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

DocumentDataValue = typing.Union[
    str,
    float,
    int,
    bool,
    typing.Dict[str, typing.Optional[typing.Any]],
    typing.List[typing.Optional[typing.Any]],
    dt.datetime,
]
