# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class Custom(UncheckedBaseModel):
    text_extractor_type: typing.Literal["custom"] = "custom"
    selectors: typing.Optional[str] = None
    exclude_selectors: typing.Optional[str] = pydantic.Field(default=None)
    """
    Enter a comma-separated list of classes, IDs, or tags to exclude from the content.
    """

    exclude_common_elements: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Exclude common elements like headers, footers, and navigation menus.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
