# This file was auto-generated by Fern from our API Definition.

import typing

from .api_key_identity_details import ApiKeyIdentityDetails
from .user_identity_details import UserIdentityDetails

LegacyIdentityDetails = typing.Union[UserIdentityDetails, ApiKeyIdentityDetails]
