# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.workflow_run_response import WorkflowRunResponse
from .workflows_run_with_config_response_zero import WorkflowsRunWithConfigResponseZero

WorkflowsRunWithConfigResponse = typing.Union[WorkflowsRunWithConfigResponseZero, WorkflowRunResponse]
