# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .table_view_settings_row_height import TableViewSettingsRowHeight


class TableViewSettings(UncheckedBaseModel):
    column_visibility: typing.Optional[typing.Dict[str, bool]] = None
    column_order: typing.Optional[typing.List[str]] = None
    column_widths: typing.Optional[typing.Dict[str, int]] = None
    type: typing.Literal["table"] = "table"
    row_height: typing.Optional[TableViewSettingsRowHeight] = None
    show_row_numbers: typing.Optional[bool] = None
    wrap_text: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
