# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ActionType,
    Actor,
    ActorIdentity,
    ActorIdentityId,
    ActorIdentityType,
    AgentAutomationConfig,
    AgentRevision,
    AgentRevisionModel,
    AgentRevisionResponseStyle,
    AiAgent,
    ApiKeyAuthType,
    ApiKeyIdentity,
    ApiKeyIdentityDetails,
    BareInput,
    BareOutput,
    Baseline,
    Billing,
    BillingCycle,
    BillingCycles,
    BillingUsage,
    BlockConfigItemBoolean,
    BlockConfigItemJson,
    BlockConfigItemLlm,
    BlockConfigItemNumber,
    BlockConfigItemNumberDefaultValue,
    BlockConfigItemNumberMaximumValue,
    BlockConfigItemNumberMinimumValue,
    BlockConfigItemNumberValue,
    BlockConfigItemSelect,
    BlockConfigItemTextLong,
    BlockConfigItemTextLongValue,
    BlockConfigItemTextShort,
    BlockInput,
    BlockInputBlockConfigItem,
    BlockOutput,
    BlockOutputBlockConfigItem,
    BlockRun,
    BlockRunCompleted,
    BlockRunCompletedData,
    BlockRunCompletedEnvironment,
    BlockRunFailed,
    BlockRunFailedData,
    BlockRunFailedEnvironment,
    BlockRunStarted,
    BlockRunStartedData,
    BlockRunStartedEnvironment,
    BlockRunUsage,
    BlockStateUpdated,
    BlockStateUpdatedData,
    BlockStateUpdatedDataUpdateType,
    BlockStateUpdatedEnvironment,
    CancelResponse,
    CardDisplayField,
    Channel,
    CheckBoxColumn,
    CheckBoxColumnAutomationConfig,
    Collection,
    CollectionConfig,
    CollectionDestination,
    CollectionViewStateInput,
    CollectionViewStateInputViewsValue,
    CollectionViewStateOutput,
    CollectionViewStateOutputViewsValue,
    ColumnType,
    ColumnTypeBase,
    ColumnTypeBaseAutomationConfig,
    Condition,
    ConditionField,
    ConditionOperator,
    ConnectIntegrationRequestAuthType,
    Copilot,
    CopilotConfig,
    CopilotConfigCodeTheme,
    CopilotConfigFabValue,
    CopilotConfigMode,
    CreateIntegrationsResponse,
    CreateTagResponse,
    CronTriggerConfig,
    CronTriggerConfigAction,
    Custom,
    DailyUsage,
    DataType,
    DateTimeColumn,
    DateTimeColumnAutomationConfig,
    DefaultInput,
    DefaultOutput,
    DeleteTriggerResponse,
    DeleteViewResponse,
    Dependency,
    Dimensions,
    Document,
    DocumentCreatedBy,
    DocumentDataValue,
    DocumentLastUpdatedBy,
    DocumentResponse,
    EdgeUi,
    Environment,
    EnvironmentConfig,
    EnvironmentDeploymentConfig,
    EnvironmentDeploymentConfigRevisionLookup,
    EnvironmentDeploymentDocument,
    EventVersion,
    ExecuteTriggerResponse,
    Favor,
    FavoriteItem,
    File,
    FilesAttribute,
    FilesResponse,
    FilterOperator,
    FilterType,
    FollowupEmailRequest,
    FriendlyInvoice,
    FriendlyPaymentMethods,
    Html2Text,
    Http,
    HttpValidationError,
    Identity,
    IdentityDetails,
    IdentityTypes,
    Integration,
    IntegrationAuthType,
    IntegrationConnection,
    IntegrationConnectionAuthType,
    IntegrationConnectionIntegrationType,
    IntegrationWithConnections,
    IntegrationWithConnectionsId,
    Interval,
    IntervalTypes,
    Invoice,
    InvoiceMeta,
    InvoiceStatus,
    JsonColumn,
    JsonColumnAutomationConfig,
    KanbanViewInput,
    KanbanViewOutput,
    KanbanViewSettings,
    LegacyIdentity,
    LegacyIdentityDetails,
    LineItem,
    ListTagsResponse,
    ListTriggersResponse,
    Mapping,
    MarkDownWithContext,
    MarkdownColumn,
    MarkdownColumnAutomationConfig,
    MarkdownSplitterConfig,
    McpAuthType,
    Message,
    MessageChunk,
    ModelProvider,
    MultiPageCrawlerSettingsInput,
    MultiPageCrawlerSettingsInputScraper,
    MultiPageCrawlerSettingsInputTextExtractor,
    MultiPageCrawlerSettingsOutput,
    MultiPageCrawlerSettingsOutputScraper,
    MultiPageCrawlerSettingsOutputTextExtractor,
    MultiSelectColumn,
    MultiSelectColumnAutomationConfig,
    NodeUi,
    Notification,
    NotificationAction,
    NotificationActionType,
    NotificationSeverity,
    NotificationType,
    NotionFilterBy,
    NotionFilterOptions,
    NumberColumn,
    NumberColumnAutomationConfig,
    NumberColumnDefault,
    NumberColumnMaxValue,
    NumberColumnMinValue,
    OAuthAuthType,
    Organization,
    ParagraphSplitterConfig,
    Participant,
    ParticipantType,
    PlaceholderInput,
    PlaceholderInputType,
    PlaceholderOutput,
    PlaceholderOutputType,
    PlanTypes,
    Playwright,
    PlaywrightWaitForLoadState,
    Position,
    Prompt,
    PromptRole,
    QuerySort,
    Readability,
    RecursiveSplitterConfig,
    RelationColumn,
    RelationColumnAutomationConfig,
    ReqBody,
    RequestBody,
    ResponseModelUsage,
    Result,
    Rule,
    RulesInput,
    RulesOutput,
    RunLog,
    RunLogPagination,
    Schedule,
    SchemaResponse,
    ScoutUser,
    SelectColumn,
    SelectColumnAutomationConfig,
    SelectOptionItem,
    SentenceSplitterConfig,
    ServiceInfo,
    SinglePageCrawlerSettingsInput,
    SinglePageCrawlerSettingsInputScraper,
    SinglePageCrawlerSettingsInputTextExtractor,
    SinglePageCrawlerSettingsOutput,
    SinglePageCrawlerSettingsOutputScraper,
    SinglePageCrawlerSettingsOutputTextExtractor,
    SitemapCrawlerSettingsInput,
    SitemapCrawlerSettingsInputScraper,
    SitemapCrawlerSettingsInputTextExtractor,
    SitemapCrawlerSettingsOutput,
    SitemapCrawlerSettingsOutputScraper,
    SitemapCrawlerSettingsOutputTextExtractor,
    SlackEventResponse,
    SlackTriggerConfigInput,
    SlackTriggerConfigInputAction,
    SlackTriggerConfigOutput,
    SlackTriggerConfigOutputAction,
    SlackUrlVerification,
    SortDirection,
    SourceArchetype,
    SourceArchetypeIntegrationVersion,
    SourceSync,
    SourceSyncCrawlSettingsInput,
    SourceSyncCrawlSettingsOutput,
    SourceSyncGoogleDriveSettings,
    SourceSyncNotionSettingsInput,
    SourceSyncNotionSettingsOutput,
    SourceSyncPageCrawlSettingsInput,
    SourceSyncPageCrawlSettingsOutput,
    SourceSyncSitemapSettingsInput,
    SourceSyncSitemapSettingsOutput,
    SourceSyncWebsiteSettings,
    SourceSyncWebsiteSettingsSplitter,
    SrcAppHttpRoutesBillingBillingHourlyData,
    SrcAppHttpRoutesBillingBillingHourlyResponse,
    SrcAppHttpRoutesBillingChangeBillingPlanResponse,
    SrcAppHttpRoutesBillingCreatePortalSessionData,
    SrcAppHttpRoutesBillingCreatePortalSessionResponse,
    SrcAppHttpRoutesBillingFreePlanUsageData,
    SrcAppHttpRoutesBillingFreePlanUsageResponse,
    SrcAppHttpRoutesBillingGetBillingData,
    SrcAppHttpRoutesBillingGetBillingResponse,
    SrcAppHttpRoutesBillingGetInfoGetInfoResponse,
    SrcAppHttpRoutesBillingGetInvoicesData,
    SrcAppHttpRoutesBillingGetInvoicesResponse,
    SrcAppHttpRoutesBillingGetNotificationsResponse,
    SrcAppHttpRoutesBillingRenewPlansData,
    SrcAppHttpRoutesBillingRenewPlansResponse,
    SrcAppHttpRoutesCollectionCreateCollectionResponse,
    SrcAppHttpRoutesCollectionCreateSyncResponse,
    SrcAppHttpRoutesCollectionCreateTableResponse,
    SrcAppHttpRoutesCollectionDeleteCollectionResponse,
    SrcAppHttpRoutesCollectionDeleteDocumentsResponse,
    SrcAppHttpRoutesCollectionDeleteSyncResponse,
    SrcAppHttpRoutesCollectionDeleteTableResponse,
    SrcAppHttpRoutesCollectionGetCollectionResponse,
    SrcAppHttpRoutesCollectionGetCollectionsResponse,
    SrcAppHttpRoutesCollectionGetDocumentResponse,
    SrcAppHttpRoutesCollectionGetDocumentsResponse,
    SrcAppHttpRoutesCollectionGetSyncResponse,
    SrcAppHttpRoutesCollectionGetTableResponse,
    SrcAppHttpRoutesCollectionGetTablesResponse,
    SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel,
    SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel,
    SrcAppHttpRoutesCollectionParseFileResponse,
    SrcAppHttpRoutesCollectionSyncTableResponse,
    SrcAppHttpRoutesCollectionUpdateCollectionResponse,
    SrcAppHttpRoutesCollectionUpdateDocumentResponse,
    SrcAppHttpRoutesCollectionUpdateSyncResponse,
    SrcAppHttpRoutesCollectionUpdateTableResponse,
    SrcAppHttpRoutesInboxHandleMessageIncomingMessage,
    SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent,
    SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType,
    SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem,
    SrcAppHttpRoutesOnboardingFollowupEmailsData,
    SrcAppHttpRoutesOnboardingFollowupEmailsResponse,
    SrcAppHttpRoutesOnboardingHandleGetMeResponse,
    SrcAppHttpRoutesOnboardingHandleUpdateMeResponse,
    SrcAppHttpRoutesRootGetInfoResponse,
    SrcAppHttpRoutesTriggerCreateTriggerResponse,
    SrcAppHttpRoutesWorldInteractIncomingMessage,
    SrcAppHttpRoutesWorldInteractIncomingMessageContent,
    SrcAppHttpRoutesWorldInteractIncomingMessageContentItem,
    SrcAppHttpRoutesWorldInteractInteractionRequest,
    SrcHandlersCreateCopilotResponse,
    SrcHandlersCreateWorkflowResponse,
    SrcHandlersCreateWorkflowRevisionResponse,
    SrcHandlersDeleteCopilotResponse,
    SrcHandlersDeleteWorkflowResponse,
    SrcHandlersDeleteWorkflowRevisionResponse,
    SrcHandlersGetCopilotResponse,
    SrcHandlersGetWorkflowEnvironmentsResponse,
    SrcHandlersGetWorkflowResponse,
    SrcHandlersListCopilotsResponse,
    SrcHandlersListWorkflowRevisionsResponse,
    SrcHandlersListWorkflowsResponse,
    SrcHandlersPromoteWorkflowRevisionResponse,
    SrcHandlersUpdateCopilotResponse,
    SrcHandlersUpdateWorkflowEnvironmentResponse,
    SrcHandlersUpdateWorkflowResponse,
    StripeProvider,
    StripeProviderMeta,
    Subscription,
    Sync,
    SyncConfigInput,
    SyncConfigInputSourceSettings,
    SyncConfigOutput,
    SyncConfigOutputSourceSettings,
    Table,
    TableConfigOutput,
    TableConfigOutputSchemaItem,
    TableViewInput,
    TableViewOutput,
    TableViewSettings,
    TableViewSettingsRowHeight,
    Tag,
    TextExtractor,
    TextExtractorConfig,
    TextLongColumn,
    TextLongColumnAutomationConfig,
    TextShortColumn,
    TextShortColumnAutomationConfig,
    Tool,
    ToolsData,
    ToolsResponse,
    TrafilaturaInput,
    TrafilaturaInputTrafilaturaType,
    TrafilaturaOutput,
    TrafilaturaOutputTrafilaturaType,
    Trigger,
    TriggerStatus,
    TriggerTriggerConfig,
    TypescriptAutomationConfig,
    Units,
    UpdateCronAuthResponse,
    UpdateTagResponse,
    UpdateTriggerResponse,
    UrlColumn,
    UrlColumnAutomationConfig,
    Usage,
    UsageTypes,
    User,
    UserIdentity,
    UserIdentityDetails,
    ValidationError,
    ValidationErrorLocItem,
    ViewFilter,
    ViewListResponse,
    ViewListResponseDataItem,
    ViewQueryInput,
    ViewQueryOutput,
    ViewResponse,
    ViewResponseData,
    ViewStateResponse,
    ViewVisibility,
    Workflow,
    WorkflowActor,
    WorkflowActorType,
    WorkflowAutomationConfig,
    WorkflowConfigInput,
    WorkflowConfigOutput,
    WorkflowExecute,
    WorkflowNoteInput,
    WorkflowNoteOutput,
    WorkflowRun,
    WorkflowRunCompleted,
    WorkflowRunCompletedData,
    WorkflowRunCompletedEnvironment,
    WorkflowRunFailed,
    WorkflowRunFailedData,
    WorkflowRunFailedEnvironment,
    WorkflowRunResponse,
    WorkflowRunStarted,
    WorkflowRunStartedData,
    WorkflowRunStartedEnvironment,
    WorkflowRunStateValue,
    WorkflowRunStopReason,
    WorkflowRunStreamResponse,
)
from .errors import UnprocessableEntityError
from . import (
    collections,
    copilots,
    documents,
    environments,
    integrations,
    organizations,
    revisions,
    sources,
    syncs,
    tables,
    triggers,
    usage,
    workflow_logs,
    workflows,
)
from .client import AsyncScout, Scout
from .collections import (
    CreateViewRequestSettings,
    CreateViewRequestType,
    UpdateViewRequestSettings,
    UpdateViewRequestType,
)
from .documents import (
    DocumentsCreateRequestBody,
    DocumentsCreateRequestBodyItemValue,
    DocumentsCreateRequestBodyOneValue,
    DocumentsCreateRequestBodyZeroValue,
    DocumentsUpdateBatchRequestBody,
    DocumentsUpdateBatchRequestBodyItemValue,
    DocumentsUpdateBatchRequestBodyOneValue,
    DocumentsUpdateBatchRequestBodyZeroValue,
    DocumentsUpdateRequestValue,
)
from .environment import ScoutEnvironment
from .tables import TableConfigInputSchemaItem, TableDataSchemaItem
from .triggers import TriggersCreateRequest, TriggersExecuteSlackResponse, TriggersUpdateRequest
from .version import __version__
from .workflow_logs import WorkflowLogsListLogsResponse
from .workflows import (
    SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue,
    WorkflowsRunRequestInputsValue,
    WorkflowsRunStreamRequestInputsValue,
    WorkflowsRunWithConfigResponse,
    WorkflowsRunWithConfigResponseZero,
)

__all__ = [
    "ActionType",
    "Actor",
    "ActorIdentity",
    "ActorIdentityId",
    "ActorIdentityType",
    "AgentAutomationConfig",
    "AgentRevision",
    "AgentRevisionModel",
    "AgentRevisionResponseStyle",
    "AiAgent",
    "ApiKeyAuthType",
    "ApiKeyIdentity",
    "ApiKeyIdentityDetails",
    "AsyncScout",
    "BareInput",
    "BareOutput",
    "Baseline",
    "Billing",
    "BillingCycle",
    "BillingCycles",
    "BillingUsage",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRun",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "CancelResponse",
    "CardDisplayField",
    "Channel",
    "CheckBoxColumn",
    "CheckBoxColumnAutomationConfig",
    "Collection",
    "CollectionConfig",
    "CollectionDestination",
    "CollectionViewStateInput",
    "CollectionViewStateInputViewsValue",
    "CollectionViewStateOutput",
    "CollectionViewStateOutputViewsValue",
    "ColumnType",
    "ColumnTypeBase",
    "ColumnTypeBaseAutomationConfig",
    "Condition",
    "ConditionField",
    "ConditionOperator",
    "ConnectIntegrationRequestAuthType",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigCodeTheme",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "CreateIntegrationsResponse",
    "CreateTagResponse",
    "CreateViewRequestSettings",
    "CreateViewRequestType",
    "CronTriggerConfig",
    "CronTriggerConfigAction",
    "Custom",
    "DailyUsage",
    "DataType",
    "DateTimeColumn",
    "DateTimeColumnAutomationConfig",
    "DefaultInput",
    "DefaultOutput",
    "DeleteTriggerResponse",
    "DeleteViewResponse",
    "Dependency",
    "Dimensions",
    "Document",
    "DocumentCreatedBy",
    "DocumentDataValue",
    "DocumentLastUpdatedBy",
    "DocumentResponse",
    "DocumentsCreateRequestBody",
    "DocumentsCreateRequestBodyItemValue",
    "DocumentsCreateRequestBodyOneValue",
    "DocumentsCreateRequestBodyZeroValue",
    "DocumentsUpdateBatchRequestBody",
    "DocumentsUpdateBatchRequestBodyItemValue",
    "DocumentsUpdateBatchRequestBodyOneValue",
    "DocumentsUpdateBatchRequestBodyZeroValue",
    "DocumentsUpdateRequestValue",
    "EdgeUi",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EventVersion",
    "ExecuteTriggerResponse",
    "Favor",
    "FavoriteItem",
    "File",
    "FilesAttribute",
    "FilesResponse",
    "FilterOperator",
    "FilterType",
    "FollowupEmailRequest",
    "FriendlyInvoice",
    "FriendlyPaymentMethods",
    "Html2Text",
    "Http",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "Integration",
    "IntegrationAuthType",
    "IntegrationConnection",
    "IntegrationConnectionAuthType",
    "IntegrationConnectionIntegrationType",
    "IntegrationWithConnections",
    "IntegrationWithConnectionsId",
    "Interval",
    "IntervalTypes",
    "Invoice",
    "InvoiceMeta",
    "InvoiceStatus",
    "JsonColumn",
    "JsonColumnAutomationConfig",
    "KanbanViewInput",
    "KanbanViewOutput",
    "KanbanViewSettings",
    "LegacyIdentity",
    "LegacyIdentityDetails",
    "LineItem",
    "ListTagsResponse",
    "ListTriggersResponse",
    "Mapping",
    "MarkDownWithContext",
    "MarkdownColumn",
    "MarkdownColumnAutomationConfig",
    "MarkdownSplitterConfig",
    "McpAuthType",
    "Message",
    "MessageChunk",
    "ModelProvider",
    "MultiPageCrawlerSettingsInput",
    "MultiPageCrawlerSettingsInputScraper",
    "MultiPageCrawlerSettingsInputTextExtractor",
    "MultiPageCrawlerSettingsOutput",
    "MultiPageCrawlerSettingsOutputScraper",
    "MultiPageCrawlerSettingsOutputTextExtractor",
    "MultiSelectColumn",
    "MultiSelectColumnAutomationConfig",
    "NodeUi",
    "Notification",
    "NotificationAction",
    "NotificationActionType",
    "NotificationSeverity",
    "NotificationType",
    "NotionFilterBy",
    "NotionFilterOptions",
    "NumberColumn",
    "NumberColumnAutomationConfig",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "OAuthAuthType",
    "Organization",
    "ParagraphSplitterConfig",
    "Participant",
    "ParticipantType",
    "PlaceholderInput",
    "PlaceholderInputType",
    "PlaceholderOutput",
    "PlaceholderOutputType",
    "PlanTypes",
    "Playwright",
    "PlaywrightWaitForLoadState",
    "Position",
    "Prompt",
    "PromptRole",
    "QuerySort",
    "Readability",
    "RecursiveSplitterConfig",
    "RelationColumn",
    "RelationColumnAutomationConfig",
    "ReqBody",
    "RequestBody",
    "ResponseModelUsage",
    "Result",
    "Rule",
    "RulesInput",
    "RulesOutput",
    "RunLog",
    "RunLogPagination",
    "Schedule",
    "SchemaResponse",
    "Scout",
    "ScoutEnvironment",
    "ScoutUser",
    "SelectColumn",
    "SelectColumnAutomationConfig",
    "SelectOptionItem",
    "SentenceSplitterConfig",
    "ServiceInfo",
    "SinglePageCrawlerSettingsInput",
    "SinglePageCrawlerSettingsInputScraper",
    "SinglePageCrawlerSettingsInputTextExtractor",
    "SinglePageCrawlerSettingsOutput",
    "SinglePageCrawlerSettingsOutputScraper",
    "SinglePageCrawlerSettingsOutputTextExtractor",
    "SitemapCrawlerSettingsInput",
    "SitemapCrawlerSettingsInputScraper",
    "SitemapCrawlerSettingsInputTextExtractor",
    "SitemapCrawlerSettingsOutput",
    "SitemapCrawlerSettingsOutputScraper",
    "SitemapCrawlerSettingsOutputTextExtractor",
    "SlackEventResponse",
    "SlackTriggerConfigInput",
    "SlackTriggerConfigInputAction",
    "SlackTriggerConfigOutput",
    "SlackTriggerConfigOutputAction",
    "SlackUrlVerification",
    "SortDirection",
    "SourceArchetype",
    "SourceArchetypeIntegrationVersion",
    "SourceSync",
    "SourceSyncCrawlSettingsInput",
    "SourceSyncCrawlSettingsOutput",
    "SourceSyncGoogleDriveSettings",
    "SourceSyncNotionSettingsInput",
    "SourceSyncNotionSettingsOutput",
    "SourceSyncPageCrawlSettingsInput",
    "SourceSyncPageCrawlSettingsOutput",
    "SourceSyncSitemapSettingsInput",
    "SourceSyncSitemapSettingsOutput",
    "SourceSyncWebsiteSettings",
    "SourceSyncWebsiteSettingsSplitter",
    "SrcAppHttpRoutesBillingBillingHourlyData",
    "SrcAppHttpRoutesBillingBillingHourlyResponse",
    "SrcAppHttpRoutesBillingChangeBillingPlanResponse",
    "SrcAppHttpRoutesBillingCreatePortalSessionData",
    "SrcAppHttpRoutesBillingCreatePortalSessionResponse",
    "SrcAppHttpRoutesBillingFreePlanUsageData",
    "SrcAppHttpRoutesBillingFreePlanUsageResponse",
    "SrcAppHttpRoutesBillingGetBillingData",
    "SrcAppHttpRoutesBillingGetBillingResponse",
    "SrcAppHttpRoutesBillingGetInfoGetInfoResponse",
    "SrcAppHttpRoutesBillingGetInvoicesData",
    "SrcAppHttpRoutesBillingGetInvoicesResponse",
    "SrcAppHttpRoutesBillingGetNotificationsResponse",
    "SrcAppHttpRoutesBillingRenewPlansData",
    "SrcAppHttpRoutesBillingRenewPlansResponse",
    "SrcAppHttpRoutesCollectionCreateCollectionResponse",
    "SrcAppHttpRoutesCollectionCreateSyncResponse",
    "SrcAppHttpRoutesCollectionCreateTableResponse",
    "SrcAppHttpRoutesCollectionDeleteCollectionResponse",
    "SrcAppHttpRoutesCollectionDeleteDocumentsResponse",
    "SrcAppHttpRoutesCollectionDeleteSyncResponse",
    "SrcAppHttpRoutesCollectionDeleteTableResponse",
    "SrcAppHttpRoutesCollectionGetCollectionResponse",
    "SrcAppHttpRoutesCollectionGetCollectionsResponse",
    "SrcAppHttpRoutesCollectionGetDocumentResponse",
    "SrcAppHttpRoutesCollectionGetDocumentsResponse",
    "SrcAppHttpRoutesCollectionGetSyncResponse",
    "SrcAppHttpRoutesCollectionGetTableResponse",
    "SrcAppHttpRoutesCollectionGetTablesResponse",
    "SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel",
    "SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel",
    "SrcAppHttpRoutesCollectionParseFileResponse",
    "SrcAppHttpRoutesCollectionSyncTableResponse",
    "SrcAppHttpRoutesCollectionUpdateCollectionResponse",
    "SrcAppHttpRoutesCollectionUpdateDocumentResponse",
    "SrcAppHttpRoutesCollectionUpdateSyncResponse",
    "SrcAppHttpRoutesCollectionUpdateTableResponse",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessage",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem",
    "SrcAppHttpRoutesOnboardingFollowupEmailsData",
    "SrcAppHttpRoutesOnboardingFollowupEmailsResponse",
    "SrcAppHttpRoutesOnboardingHandleGetMeResponse",
    "SrcAppHttpRoutesOnboardingHandleUpdateMeResponse",
    "SrcAppHttpRoutesRootGetInfoResponse",
    "SrcAppHttpRoutesTriggerCreateTriggerResponse",
    "SrcAppHttpRoutesWorldInteractIncomingMessage",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContent",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContentItem",
    "SrcAppHttpRoutesWorldInteractInteractionRequest",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersCreateWorkflowRevisionResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue",
    "StripeProvider",
    "StripeProviderMeta",
    "Subscription",
    "Sync",
    "SyncConfigInput",
    "SyncConfigInputSourceSettings",
    "SyncConfigOutput",
    "SyncConfigOutputSourceSettings",
    "Table",
    "TableConfigInputSchemaItem",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TableDataSchemaItem",
    "TableViewInput",
    "TableViewOutput",
    "TableViewSettings",
    "TableViewSettingsRowHeight",
    "Tag",
    "TextExtractor",
    "TextExtractorConfig",
    "TextLongColumn",
    "TextLongColumnAutomationConfig",
    "TextShortColumn",
    "TextShortColumnAutomationConfig",
    "Tool",
    "ToolsData",
    "ToolsResponse",
    "TrafilaturaInput",
    "TrafilaturaInputTrafilaturaType",
    "TrafilaturaOutput",
    "TrafilaturaOutputTrafilaturaType",
    "Trigger",
    "TriggerStatus",
    "TriggerTriggerConfig",
    "TriggersCreateRequest",
    "TriggersExecuteSlackResponse",
    "TriggersUpdateRequest",
    "TypescriptAutomationConfig",
    "Units",
    "UnprocessableEntityError",
    "UpdateCronAuthResponse",
    "UpdateTagResponse",
    "UpdateTriggerResponse",
    "UpdateViewRequestSettings",
    "UpdateViewRequestType",
    "UrlColumn",
    "UrlColumnAutomationConfig",
    "Usage",
    "UsageTypes",
    "User",
    "UserIdentity",
    "UserIdentityDetails",
    "ValidationError",
    "ValidationErrorLocItem",
    "ViewFilter",
    "ViewListResponse",
    "ViewListResponseDataItem",
    "ViewQueryInput",
    "ViewQueryOutput",
    "ViewResponse",
    "ViewResponseData",
    "ViewStateResponse",
    "ViewVisibility",
    "Workflow",
    "WorkflowActor",
    "WorkflowActorType",
    "WorkflowAutomationConfig",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowExecute",
    "WorkflowLogsListLogsResponse",
    "WorkflowNoteInput",
    "WorkflowNoteOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
    "WorkflowsRunRequestInputsValue",
    "WorkflowsRunStreamRequestInputsValue",
    "WorkflowsRunWithConfigResponse",
    "WorkflowsRunWithConfigResponseZero",
    "__version__",
    "collections",
    "copilots",
    "documents",
    "environments",
    "integrations",
    "organizations",
    "revisions",
    "sources",
    "syncs",
    "tables",
    "triggers",
    "usage",
    "workflow_logs",
    "workflows",
]
