# This file was auto-generated by Fern from our API Definition.

import typing

from .src_app_http_routes_world_interact_incoming_message_content_item import (
    SrcAppHttpRoutesWorldInteractIncomingMessageContentItem,
)

SrcAppHttpRoutesWorldInteractIncomingMessageContent = typing.Union[
    str,
    typing.Dict[str, typing.Optional[typing.Any]],
    typing.List[SrcAppHttpRoutesWorldInteractIncomingMessageContentItem],
]
