# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .dependency import Dependency
from .node_ui import NodeUi
from .placeholder_input_type import PlaceholderInputType


class PlaceholderInput(UncheckedBaseModel):
    block_id: str
    type: PlaceholderInputType
    ui: typing.Optional[NodeUi] = None
    dependencies: typing.Optional[typing.List[Dependency]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
