# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .select_column_automation_config import SelectColumnAutomationConfig
from .select_option_item import SelectOptionItem


class SelectColumn(UncheckedBaseModel):
    column_id: typing.Optional[str] = None
    column_display_name: typing.Optional[str] = None
    column_type: typing.Literal["select"] = "select"
    data_type: typing.Optional[typing.Literal["string"]] = None
    hidden: typing.Optional[bool] = None
    automation_config: typing.Optional[SelectColumnAutomationConfig] = pydantic.Field(default=None)
    """
    Optional automation configuration to automatically calculate values for this column
    """

    options: typing.Optional[typing.List[SelectOptionItem]] = pydantic.Field(default=None)
    """
    Available options for selection
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
