# This file was auto-generated by Fern from our API Definition.

import typing

ConditionOperator = typing.Union[
    typing.Literal[
        "Any Of", "None Of", "Is true", "Is false", "Is null", "Is not null", "Contains Any Of", "Contains None Of"
    ],
    typing.Any,
]
