# This file was auto-generated by Fern from our API Definition.

import typing

from .api_key_auth_type import ApiKeyAuthType
from .mcp_auth_type import McpAuthType
from .o_auth_auth_type import OAuthAuthType

IntegrationAuthType = typing.Union[ApiKeyAuthType, McpAuthType, OAuthAuthType]
